"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name2 in all)
    __defProp(target, name2, { get: all[name2], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/plugin.ts
var plugin_exports = {};
__export(plugin_exports, {
  netlifyPlugin: () => netlifyPlugin
});
module.exports = __toCommonJS(plugin_exports);
var import_promises = require("fs/promises");
var import_node_path = require("path");

// package.json
var name = "@netlify/remix-edge-adapter";
var version = "3.2.0";

// src/plugin.ts
var SERVER_ID = "virtual:netlify-server";
var RESOLVED_SERVER_ID = `\0${SERVER_ID}`;
var serverCode = (
  /* js */
  `
import { createRequestHandler } from "@netlify/remix-edge-adapter";
import * as build from "virtual:remix/server-build";
export default createRequestHandler({ build });
`
);
function generateEntrypoint(server, exclude = []) {
  return (
    /* js */
    `
    export { default } from "${server}";
    export const config = {
      name: "Remix server handler",
      generator: "${name}@${version}",
      cache: "manual",
      path: "/*",
      excludedPath: ${JSON.stringify(exclude)},
    };`
  );
}
function netlifyPlugin() {
  let resolvedConfig;
  let currentCommand;
  let isSsr;
  return {
    name: "vite-plugin-remix-netlify-edge",
    config(config, { command, isSsrBuild }) {
      var _a, _b;
      currentCommand = command;
      isSsr = isSsrBuild;
      if (command === "build") {
        if (isSsrBuild) {
          config.ssr = {
            ...config.ssr,
            target: "webworker",
            noExternal: true
          };
          if (typeof ((_b = (_a = config.build) == null ? void 0 : _a.rollupOptions) == null ? void 0 : _b.input) === "string") {
            config.build.rollupOptions.input = {
              server: SERVER_ID,
              index: config.build.rollupOptions.input
            };
            if (config.build.rollupOptions.output && !Array.isArray(config.build.rollupOptions.output)) {
              config.build.rollupOptions.output.entryFileNames = "[name].js";
            }
          }
        }
      }
    },
    async configResolved(config) {
      resolvedConfig = config;
    },
    async resolveId(source, importer, options) {
      if (source === "virtual:netlify-server-entry") {
        if (currentCommand === "build" && options.ssr) {
          return this.resolve("@netlify/remix-edge-adapter/entry.server", importer, {
            ...options,
            skipSelf: true
          });
        } else {
          return this.resolve("@remix-run/dev/dist/config/defaults/entry.server.node", importer, {
            ...options,
            skipSelf: true
          });
        }
      }
      if (source === SERVER_ID) {
        return RESOLVED_SERVER_ID;
      }
      return null;
    },
    load(id) {
      if (id === RESOLVED_SERVER_ID) {
        return serverCode;
      }
    },
    async writeBundle() {
      if (currentCommand === "build" && isSsr) {
        const edgeFunctionDir = (0, import_node_path.join)(resolvedConfig.root, ".netlify/edge-functions");
        const exclude = [];
        try {
          const entries = await (0, import_promises.readdir)((0, import_node_path.join)(resolvedConfig.build.outDir, "..", "client"), { withFileTypes: true });
          for (const entry of entries) {
            if (entry.isDirectory()) {
              exclude.push(`/${entry.name}/*`);
            } else if (entry.isFile()) {
              exclude.push(`/${entry.name}`);
            }
          }
        } catch {
        }
        await (0, import_promises.mkdir)(edgeFunctionDir, { recursive: true });
        await (0, import_promises.writeFile)(
          (0, import_node_path.join)(edgeFunctionDir, "remix-server.mjs"),
          generateEntrypoint((0, import_node_path.relative)(edgeFunctionDir, (0, import_node_path.join)(resolvedConfig.build.outDir, "server.js")), exclude)
        );
      }
    }
  };
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  netlifyPlugin
});
