import "./chunk-BXO7ZPPU.mjs";

// src/plugin.ts
import { writeFile, mkdir, readdir } from "node:fs/promises";
import { join, relative } from "node:path";

// package.json
var name = "@netlify/remix-edge-adapter";
var version = "3.2.0";

// src/plugin.ts
var SERVER_ID = "virtual:netlify-server";
var RESOLVED_SERVER_ID = `\0${SERVER_ID}`;
var serverCode = (
  /* js */
  `
import { createRequestHandler } from "@netlify/remix-edge-adapter";
import * as build from "virtual:remix/server-build";
export default createRequestHandler({ build });
`
);
function generateEntrypoint(server, exclude = []) {
  return (
    /* js */
    `
    export { default } from "${server}";
    export const config = {
      name: "Remix server handler",
      generator: "${name}@${version}",
      cache: "manual",
      path: "/*",
      excludedPath: ${JSON.stringify(exclude)},
    };`
  );
}
function netlifyPlugin() {
  let resolvedConfig;
  let currentCommand;
  let isSsr;
  return {
    name: "vite-plugin-remix-netlify-edge",
    config(config, { command, isSsrBuild }) {
      var _a, _b;
      currentCommand = command;
      isSsr = isSsrBuild;
      if (command === "build") {
        if (isSsrBuild) {
          config.ssr = {
            ...config.ssr,
            target: "webworker",
            noExternal: true
          };
          if (typeof ((_b = (_a = config.build) == null ? void 0 : _a.rollupOptions) == null ? void 0 : _b.input) === "string") {
            config.build.rollupOptions.input = {
              server: SERVER_ID,
              index: config.build.rollupOptions.input
            };
            if (config.build.rollupOptions.output && !Array.isArray(config.build.rollupOptions.output)) {
              config.build.rollupOptions.output.entryFileNames = "[name].js";
            }
          }
        }
      }
    },
    async configResolved(config) {
      resolvedConfig = config;
    },
    async resolveId(source, importer, options) {
      if (source === "virtual:netlify-server-entry") {
        if (currentCommand === "build" && options.ssr) {
          return this.resolve("@netlify/remix-edge-adapter/entry.server", importer, {
            ...options,
            skipSelf: true
          });
        } else {
          return this.resolve("@remix-run/dev/dist/config/defaults/entry.server.node", importer, {
            ...options,
            skipSelf: true
          });
        }
      }
      if (source === SERVER_ID) {
        return RESOLVED_SERVER_ID;
      }
      return null;
    },
    load(id) {
      if (id === RESOLVED_SERVER_ID) {
        return serverCode;
      }
    },
    async writeBundle() {
      if (currentCommand === "build" && isSsr) {
        const edgeFunctionDir = join(resolvedConfig.root, ".netlify/edge-functions");
        const exclude = [];
        try {
          const entries = await readdir(join(resolvedConfig.build.outDir, "..", "client"), { withFileTypes: true });
          for (const entry of entries) {
            if (entry.isDirectory()) {
              exclude.push(`/${entry.name}/*`);
            } else if (entry.isFile()) {
              exclude.push(`/${entry.name}`);
            }
          }
        } catch {
        }
        await mkdir(edgeFunctionDir, { recursive: true });
        await writeFile(
          join(edgeFunctionDir, "remix-server.mjs"),
          generateEntrypoint(relative(edgeFunctionDir, join(resolvedConfig.build.outDir, "server.js")), exclude)
        );
      }
    }
  };
}
export {
  netlifyPlugin
};
